nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Pmcfg

Struct Pmcfg 

#[repr(transparent)]
pub struct Pmcfg(pub u32);
Pattern-Match Interrupt Bit Slice Configuration

Tuple Fields

0: u32

Implementations

Source

impl Pmcfg

pub const fn prod_endpts0(&self) -> ProdEndpts0

Determines whether slice 0 is an endpoint. Slice 0 is not an endpoint. Slice 0 is the endpoint of a product term (minterm). Pin interrupt 0 in the NVIC is raised if the minterm evaluates as true.

pub const fn set_prod_endpts0(&mut self, val: ProdEndpts0)

Determines whether slice 0 is an endpoint. Slice 0 is not an endpoint. Slice 0 is the endpoint of a product term (minterm). Pin interrupt 0 in the NVIC is raised if the minterm evaluates as true.

pub const fn prod_endpts1(&self) -> ProdEndpts1

Determines whether slice 1 is an endpoint. Slice 1 is not an endpoint. Slice 1 is the endpoint of a product term (minterm). Pin interrupt 1 in the NVIC is raised if the minterm evaluates as true.

pub const fn set_prod_endpts1(&mut self, val: ProdEndpts1)

Determines whether slice 1 is an endpoint. Slice 1 is not an endpoint. Slice 1 is the endpoint of a product term (minterm). Pin interrupt 1 in the NVIC is raised if the minterm evaluates as true.

pub const fn prod_endpts2(&self) -> ProdEndpts2

Determines whether slice 2 is an endpoint. Slice 2 is not an endpoint. Slice 2 is the endpoint of a product term (minterm). Pin interrupt 2 in the NVIC is raised if the minterm evaluates as true.

pub const fn set_prod_endpts2(&mut self, val: ProdEndpts2)

Determines whether slice 2 is an endpoint. Slice 2 is not an endpoint. Slice 2 is the endpoint of a product term (minterm). Pin interrupt 2 in the NVIC is raised if the minterm evaluates as true.

pub const fn prod_endpts3(&self) -> ProdEndpts3

Determines whether slice 3 is an endpoint. Slice 3 is not an endpoint. Slice 3 is the endpoint of a product term (minterm). Pin interrupt 3 in the NVIC is raised if the minterm evaluates as true.

pub const fn set_prod_endpts3(&mut self, val: ProdEndpts3)

Determines whether slice 3 is an endpoint. Slice 3 is not an endpoint. Slice 3 is the endpoint of a product term (minterm). Pin interrupt 3 in the NVIC is raised if the minterm evaluates as true.

pub const fn prod_endpts4(&self) -> ProdEndpts4

Determines whether slice 4 is an endpoint. Slice 4 is not an endpoint. Slice 4 is the endpoint of a product term (minterm). Pin interrupt 4 in the NVIC is raised if the minterm evaluates as true.

pub const fn set_prod_endpts4(&mut self, val: ProdEndpts4)

Determines whether slice 4 is an endpoint. Slice 4 is not an endpoint. Slice 4 is the endpoint of a product term (minterm). Pin interrupt 4 in the NVIC is raised if the minterm evaluates as true.

pub const fn prod_endpts5(&self) -> ProdEndpts5

Determines whether slice 5 is an endpoint. Slice 5 is not an endpoint. Slice 5 is the endpoint of a product term (minterm). Pin interrupt 5 in the NVIC is raised if the minterm evaluates as true.

pub const fn set_prod_endpts5(&mut self, val: ProdEndpts5)

Determines whether slice 5 is an endpoint. Slice 5 is not an endpoint. Slice 5 is the endpoint of a product term (minterm). Pin interrupt 5 in the NVIC is raised if the minterm evaluates as true.

pub const fn prod_endpts6(&self) -> ProdEndpts6

Determines whether slice 6 is an endpoint. Slice 6 is not an endpoint. Slice 6 is the endpoint of a product term (minterm). Pin interrupt 6 in the NVIC is raised if the minterm evaluates as true.

pub const fn set_prod_endpts6(&mut self, val: ProdEndpts6)

Determines whether slice 6 is an endpoint. Slice 6 is not an endpoint. Slice 6 is the endpoint of a product term (minterm). Pin interrupt 6 in the NVIC is raised if the minterm evaluates as true.

pub const fn cfg0(&self) -> Cfg0

Match Configuration

pub const fn set_cfg0(&mut self, val: Cfg0)

Match Configuration

pub const fn cfg1(&self) -> Cfg1

Match Configuration

pub const fn set_cfg1(&mut self, val: Cfg1)

Match Configuration

pub const fn cfg2(&self) -> Cfg2

Match Configuration

pub const fn set_cfg2(&mut self, val: Cfg2)

Match Configuration

pub const fn cfg3(&self) -> Cfg3

Match Configuration

pub const fn set_cfg3(&mut self, val: Cfg3)

Match Configuration

pub const fn cfg4(&self) -> Cfg4

Match Configuration

pub const fn set_cfg4(&mut self, val: Cfg4)

Match Configuration

pub const fn cfg5(&self) -> Cfg5

Match Configuration

pub const fn set_cfg5(&mut self, val: Cfg5)

Match Configuration

pub const fn cfg6(&self) -> Cfg6

Match Configuration

pub const fn set_cfg6(&mut self, val: Cfg6)

Match Configuration

pub const fn cfg7(&self) -> Cfg7

Match Configuration

pub const fn set_cfg7(&mut self, val: Cfg7)

Match Configuration