nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Pmctrl

Struct Pmctrl 

#[repr(transparent)]
pub struct Pmctrl(pub u32);
Pattern-Match Interrupt Control

Tuple Fields

0: u32

Implementations

Source

impl Pmctrl

pub const fn sel_pmatch(&self) -> SelPmatch

Specifies whether the pin interrupts are controlled by the pin interrupt function or by the pattern-match function. If this value is 0b, interrupts are driven in response to the standard pin interrupt function. If this value is 1b, interrupts are driven in response to pattern matches.

pub const fn set_sel_pmatch(&mut self, val: SelPmatch)

Specifies whether the pin interrupts are controlled by the pin interrupt function or by the pattern-match function. If this value is 0b, interrupts are driven in response to the standard pin interrupt function. If this value is 1b, interrupts are driven in response to pattern matches.

pub const fn ena_rxev(&self) -> bool

Enables the RXEV output to the CPU and/or to a GPIO output, when the specified Boolean expression evaluates to true. If this value is 0b, RXEV output to the CPU is disabled. If this value is 1b, RXEV output to the CPU is enabled.

pub const fn set_ena_rxev(&mut self, val: bool)

Enables the RXEV output to the CPU and/or to a GPIO output, when the specified Boolean expression evaluates to true. If this value is 0b, RXEV output to the CPU is disabled. If this value is 1b, RXEV output to the CPU is enabled.

pub const fn pmat(&self) -> Pmat

Pattern Matches

pub const fn set_pmat(&mut self, val: Pmat)

Pattern Matches